# Example: Estimating WL using stem diameter at the lowest major living branch (DB) = 30 cm
db <- 30 # Stem Diameter at the Lowest Major Living Branch in cm
WL_result <- WL(db)
print(WL_result)
# Example: Handling missing value
db <- NA # Stem Diameter at the Lowest Major Living Branch in cm
WL_result <- WL(db)
print(WL_result) # Should return NA because DB is NA
Run the code above in your browser using DataLab